@@ -61,6 +61,7 @@ def get_lang_selector(language, pagename, sep=" | "):
         if lng == language:
             html += "<b>{}</b>".format(lngfmt(lng))
         else:
+            # print("20230121 {} != {}".format(lng, language))
             href = public_url + "/" + get_page_url(lng, pagename)
             if i == 0:
                 pth = docs_root.parent / "docs" / filename
@@ -69,7 +70,7 @@ def get_lang_selector(language, pagename, sep=" | "):
             else:
                 pth = docs_root.parent / (lng + "docs") / filename
                 if not pth.exists():
-                    href = lng + "/" + homename
+                    href = public_url + "/" + lng + "/" + homename
                     # print("Not found b:", pth)
             html += '<a href="{}">{}</a>'.format(href, lngfmt(lng))
     # html += "</p>"
