@@ -140,6 +140,12 @@ def configure(globals_dict, prjspec=None, **nicknames):
         #     k = '%s_srcref' % prj.nickname
         #     extlinks[str(k)] = (prj.srcref_url, '')
 
+    from synodal import REPOS_LIST
+    for r in REPOS_LIST:
+        if r.public_url and r.nickname:
+            if not r.nickname in intersphinx_mapping:
+                intersphinx_mapping[r.nickname] = (r.public_url, None)
+
     # atelier.current_project = this
     globals_dict.update(intersphinx_mapping=intersphinx_mapping)
 
